---
search:
  exclude: true
---
# リリースプロセス/変更履歴

本プロジェクトは、形式 `0.Y.Z` を用いたセマンティック バージョニングの軽微に変更したバージョンに従います。先頭の `0` は、 SDK が依然として急速に進化していることを示します。各コンポーネントの増分は次のとおりです:

## マイナー (`Y`) バージョン

ベータとしてマークされていない公開インターフェースに対する **破壊的変更** がある場合、マイナー バージョン `Y` を上げます。たとえば、`0.0.x` から `0.1.x` への変更には破壊的変更が含まれる可能性があります。

破壊的変更を避けたい場合は、プロジェクトで `0.0.x` バージョンにピン留めすることをお勧めします。

## パッチ (`Z`) バージョン

破壊的でない変更では `Z` を増やします:

- バグ修正
- 新機能
- 非公開インターフェースへの変更
- ベータ機能の更新

## 破壊的変更の変更履歴

### 0.4.0

このバージョンでは、[openai](https://pypi.org/project/openai/) パッケージ v1.x はサポート対象外になりました。 この SDK と併せて openai v2.x を使用してください。

### 0.3.0

このバージョンでは、 Realtime API のサポートが gpt-realtime モデルおよびその API インターフェース（ GA バージョン）に移行します。

### 0.2.0

このバージョンでは、これまで `Agent` を引数として受け取っていた一部の箇所が、代わりに `AgentBase` を引数として受け取るようになりました。たとえば、 MCP サーバーの `list_tools()` 呼び出しです。これは型に関する変更のみで、引き続き `Agent` オブジェクトを受け取ります。更新するには、`Agent` を `AgentBase` に置き換えて型エラーを修正するだけです。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーターが 2 つ追加されました: `run_context` と `agent`。`MCPServer` をサブクラス化するすべてのクラスに、これらのパラメーターを追加する必要があります。